@@ -77,7 +77,7 @@ class Model(object):
                     setattr(self, prop_name, value)
     
     def save(self):
-        pk = self._data.pop('__pk__')
+        pk = self._data.pop('__pk__', None)
         if pk is None:
             assert 0, 'not set primary key "%s" on model "%s"' % (
                 self._pk_name, self.__class__.__name__)
@@ -165,7 +165,7 @@ class Model(object):
             import gdbm
             return gdbm.open(cls.__filename__, 'c')
         elif cls.__db_type__ == 'dict':
-            return {}
+            return DictDBM(cls.__filename__)
         assert 0, 'this db is not supported'
     
     @class_cached_property
@@ -318,6 +318,30 @@ class CompressedProperty(CompressedStringProperty):
         return self.dumper.loads(value)
 
 
+class DictDBM(dict):
+    '''Dummy dbm for tests'''
+    def __init__(self, filename=None):
+        self.filename = filename
+        if filename:
+            try:
+                super(self.__class__, self).__init__(
+                    **marshal.load(open(filename)))
+            except IOError:
+                pass
+    
+    def __setitem__(self, key, value):
+        super(self.__class__, self).__setitem__(key, value)
+        self.save()
+        
+    def clear(self):
+        super(self.__class__, self).clear()
+        self.save()
+        
+    def save(self):
+        if self.filename:
+            marshal.dump(dict(self), open(self.filename, 'w'))
+
+
 if __name__ == "__main__":
     import doctest
     doctest.testmod()
